import http.cookies
import os

import grpc

from couchers.proto import auth_pb2, auth_pb2_grpc
from couchers.services import get_all_stubs

SERVER_ADDRESS = os.getenv("COUCHERS_SERVER_ADDRESS", "api.couchers.org:8443")
# whether to use TLS/SSL or not. CONNECT_INSECURE only works on localhost
ENABLE_TLS = os.getenv("CONNECT_INSECURE", "0") != "1"


class _CookieCreds:
    def __init__(self, cookie_name, cookie_value):
        self.cookie_name = cookie_name
        self.cookie_value = cookie_value

    def __call__(self, context, callback):
        callback((("cookie", f"{self.cookie_name}={self.cookie_value}"),), None)


class _MetadataKeeperInterceptor(grpc.UnaryUnaryClientInterceptor):
    def __init__(self):
        self.latest_headers = {}

    def intercept_unary_unary(self, continuation, client_call_details, request):
        call = continuation(client_call_details, request)
        self.latest_headers = dict(call.initial_metadata())
        return call


def get_api_key(username, password):
    with create_channel() as channel:
        metadata_interceptor = _MetadataKeeperInterceptor()
        channel = grpc.intercept_channel(channel, metadata_interceptor)
        auth = auth_pb2_grpc.AuthStub(channel)
        auth.Authenticate(auth_pb2.AuthReq(user=username, password=password))
        return http.cookies.SimpleCookie(metadata_interceptor.latest_headers["set-cookie"])["couchers-sesh"].value


def create_channel(api_key=None):
    if ENABLE_TLS:
        creds = grpc.ssl_channel_credentials()
    else:
        creds = grpc.local_channel_credentials()

    if api_key:
        cookie_creds = grpc.metadata_call_credentials(_CookieCreds("couchers-sesh", api_key))
        creds = grpc.composite_channel_credentials(creds, cookie_creds)

    return grpc.secure_channel(SERVER_ADDRESS, creds)


def get_client(username, password):
    api_key = get_api_key(username, password)
    channel = create_channel(api_key)
    stubs = get_all_stubs(channel)
    return type("__Client", (), stubs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2
from . import communities_pb2 as communities__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='admin.proto',
  package='org.couchers.api.admin',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0b\x61\x64min.proto\x12\x16org.couchers.api.admin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\x1a\x11\x63ommunities.proto\"-\n\x19GetUserEmailByUsernameReq\x12\x10\n\x08username\x18\x01 \x01(\t\"&\n\x13GetUserEmailByIdReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\"1\n\x0fGetUserEmailRes\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x03\"\x81\x01\n\x12\x43reateCommunityReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x11\n\tadmin_ids\x18\x05 \x03(\x03\x12\x0f\n\x07geojson\x18\x06 \x01(\t\"\x1d\n\nBanUserReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\" \n\rDeleteUserReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x32\xf3\x03\n\x05\x41\x64min\x12v\n\x16GetUserEmailByUsername\x12\x31.org.couchers.api.admin.GetUserEmailByUsernameReq\x1a\'.org.couchers.api.admin.GetUserEmailRes\"\x00\x12j\n\x10GetUserEmailById\x12+.org.couchers.api.admin.GetUserEmailByIdReq\x1a\'.org.couchers.api.admin.GetUserEmailRes\"\x00\x12h\n\x0f\x43reateCommunity\x12*.org.couchers.api.admin.CreateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12G\n\x07\x42\x61nUser\x12\".org.couchers.api.admin.BanUserReq\x1a\x16.google.protobuf.Empty\"\x00\x12M\n\nDeleteUser\x12%.org.couchers.api.admin.DeleteUserReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,communities__pb2.DESCRIPTOR,])




_GETUSEREMAILBYUSERNAMEREQ = _descriptor.Descriptor(
  name='GetUserEmailByUsernameReq',
  full_name='org.couchers.api.admin.GetUserEmailByUsernameReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.api.admin.GetUserEmailByUsernameReq.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=151,
)


_GETUSEREMAILBYIDREQ = _descriptor.Descriptor(
  name='GetUserEmailByIdReq',
  full_name='org.couchers.api.admin.GetUserEmailByIdReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.admin.GetUserEmailByIdReq.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=191,
)


_GETUSEREMAILRES = _descriptor.Descriptor(
  name='GetUserEmailRes',
  full_name='org.couchers.api.admin.GetUserEmailRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='org.couchers.api.admin.GetUserEmailRes.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.admin.GetUserEmailRes.user_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=242,
)


_CREATECOMMUNITYREQ = _descriptor.Descriptor(
  name='CreateCommunityReq',
  full_name='org.couchers.api.admin.CreateCommunityReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.api.admin.CreateCommunityReq.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='org.couchers.api.admin.CreateCommunityReq.slug', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='org.couchers.api.admin.CreateCommunityReq.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_node_id', full_name='org.couchers.api.admin.CreateCommunityReq.parent_node_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_ids', full_name='org.couchers.api.admin.CreateCommunityReq.admin_ids', index=4,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geojson', full_name='org.couchers.api.admin.CreateCommunityReq.geojson', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=374,
)


_BANUSERREQ = _descriptor.Descriptor(
  name='BanUserReq',
  full_name='org.couchers.api.admin.BanUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.admin.BanUserReq.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=405,
)


_DELETEUSERREQ = _descriptor.Descriptor(
  name='DeleteUserReq',
  full_name='org.couchers.api.admin.DeleteUserReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.api.admin.DeleteUserReq.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=439,
)

DESCRIPTOR.message_types_by_name['GetUserEmailByUsernameReq'] = _GETUSEREMAILBYUSERNAMEREQ
DESCRIPTOR.message_types_by_name['GetUserEmailByIdReq'] = _GETUSEREMAILBYIDREQ
DESCRIPTOR.message_types_by_name['GetUserEmailRes'] = _GETUSEREMAILRES
DESCRIPTOR.message_types_by_name['CreateCommunityReq'] = _CREATECOMMUNITYREQ
DESCRIPTOR.message_types_by_name['BanUserReq'] = _BANUSERREQ
DESCRIPTOR.message_types_by_name['DeleteUserReq'] = _DELETEUSERREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetUserEmailByUsernameReq = _reflection.GeneratedProtocolMessageType('GetUserEmailByUsernameReq', (_message.Message,), {
  'DESCRIPTOR' : _GETUSEREMAILBYUSERNAMEREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.admin.GetUserEmailByUsernameReq)
  })
_sym_db.RegisterMessage(GetUserEmailByUsernameReq)

GetUserEmailByIdReq = _reflection.GeneratedProtocolMessageType('GetUserEmailByIdReq', (_message.Message,), {
  'DESCRIPTOR' : _GETUSEREMAILBYIDREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.admin.GetUserEmailByIdReq)
  })
_sym_db.RegisterMessage(GetUserEmailByIdReq)

GetUserEmailRes = _reflection.GeneratedProtocolMessageType('GetUserEmailRes', (_message.Message,), {
  'DESCRIPTOR' : _GETUSEREMAILRES,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.admin.GetUserEmailRes)
  })
_sym_db.RegisterMessage(GetUserEmailRes)

CreateCommunityReq = _reflection.GeneratedProtocolMessageType('CreateCommunityReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMMUNITYREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.admin.CreateCommunityReq)
  })
_sym_db.RegisterMessage(CreateCommunityReq)

BanUserReq = _reflection.GeneratedProtocolMessageType('BanUserReq', (_message.Message,), {
  'DESCRIPTOR' : _BANUSERREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.admin.BanUserReq)
  })
_sym_db.RegisterMessage(BanUserReq)

DeleteUserReq = _reflection.GeneratedProtocolMessageType('DeleteUserReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQ,
  '__module__' : 'admin_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.admin.DeleteUserReq)
  })
_sym_db.RegisterMessage(DeleteUserReq)



_ADMIN = _descriptor.ServiceDescriptor(
  name='Admin',
  full_name='org.couchers.api.admin.Admin',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\004',
  create_key=_descriptor._internal_create_key,
  serialized_start=442,
  serialized_end=941,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetUserEmailByUsername',
    full_name='org.couchers.api.admin.Admin.GetUserEmailByUsername',
    index=0,
    containing_service=None,
    input_type=_GETUSEREMAILBYUSERNAMEREQ,
    output_type=_GETUSEREMAILRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserEmailById',
    full_name='org.couchers.api.admin.Admin.GetUserEmailById',
    index=1,
    containing_service=None,
    input_type=_GETUSEREMAILBYIDREQ,
    output_type=_GETUSEREMAILRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCommunity',
    full_name='org.couchers.api.admin.Admin.CreateCommunity',
    index=2,
    containing_service=None,
    input_type=_CREATECOMMUNITYREQ,
    output_type=communities__pb2._COMMUNITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BanUser',
    full_name='org.couchers.api.admin.Admin.BanUser',
    index=3,
    containing_service=None,
    input_type=_BANUSERREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUser',
    full_name='org.couchers.api.admin.Admin.DeleteUser',
    index=4,
    containing_service=None,
    input_type=_DELETEUSERREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADMIN)

DESCRIPTOR.services_by_name['Admin'] = _ADMIN

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import admin_pb2 as admin__pb2
from . import communities_pb2 as communities__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AdminStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserEmailByUsername = channel.unary_unary(
                '/org.couchers.api.admin.Admin/GetUserEmailByUsername',
                request_serializer=admin__pb2.GetUserEmailByUsernameReq.SerializeToString,
                response_deserializer=admin__pb2.GetUserEmailRes.FromString,
                )
        self.GetUserEmailById = channel.unary_unary(
                '/org.couchers.api.admin.Admin/GetUserEmailById',
                request_serializer=admin__pb2.GetUserEmailByIdReq.SerializeToString,
                response_deserializer=admin__pb2.GetUserEmailRes.FromString,
                )
        self.CreateCommunity = channel.unary_unary(
                '/org.couchers.api.admin.Admin/CreateCommunity',
                request_serializer=admin__pb2.CreateCommunityReq.SerializeToString,
                response_deserializer=communities__pb2.Community.FromString,
                )
        self.BanUser = channel.unary_unary(
                '/org.couchers.api.admin.Admin/BanUser',
                request_serializer=admin__pb2.BanUserReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/org.couchers.api.admin.Admin/DeleteUser',
                request_serializer=admin__pb2.DeleteUserReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class AdminServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserEmailByUsername(self, request, context):
        """Gets user email based user_name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserEmailById(self, request, context):
        """Gets user email based user_id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCommunity(self, request, context):
        """Creates a new community
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BanUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUserEmailByUsername': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserEmailByUsername,
                    request_deserializer=admin__pb2.GetUserEmailByUsernameReq.FromString,
                    response_serializer=admin__pb2.GetUserEmailRes.SerializeToString,
            ),
            'GetUserEmailById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserEmailById,
                    request_deserializer=admin__pb2.GetUserEmailByIdReq.FromString,
                    response_serializer=admin__pb2.GetUserEmailRes.SerializeToString,
            ),
            'CreateCommunity': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCommunity,
                    request_deserializer=admin__pb2.CreateCommunityReq.FromString,
                    response_serializer=communities__pb2.Community.SerializeToString,
            ),
            'BanUser': grpc.unary_unary_rpc_method_handler(
                    servicer.BanUser,
                    request_deserializer=admin__pb2.BanUserReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=admin__pb2.DeleteUserReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.admin.Admin', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Admin(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserEmailByUsername(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.admin.Admin/GetUserEmailByUsername',
            admin__pb2.GetUserEmailByUsernameReq.SerializeToString,
            admin__pb2.GetUserEmailRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserEmailById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.admin.Admin/GetUserEmailById',
            admin__pb2.GetUserEmailByIdReq.SerializeToString,
            admin__pb2.GetUserEmailRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCommunity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.admin.Admin/CreateCommunity',
            admin__pb2.CreateCommunityReq.SerializeToString,
            communities__pb2.Community.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BanUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.admin.Admin/BanUser',
            admin__pb2.BanUserReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.admin.Admin/DeleteUser',
            admin__pb2.DeleteUserReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
